========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/badges/searchlight.svg
    :target: https://governance.openstack.org/reference/tags/index.html
    :alt: Searchlight is an official OpenStack project as indicated by
          the "project:official" badge
.. NOTE(rosmaita): the alt text above will have to be updated when
   additional tags are asserted for Searchlight.  (The SVG in the
   governance repo is updated automatically.)

.. Change things from this point on

===========
Searchlight
===========

The Searchlight project provides indexing and search capabilities across
OpenStack resources. Its goal is to achieve high performance and flexible
querying combined with near real-time indexing.

Use the following resources to learn more:

* `Official Searchlight documentation <https://docs.openstack.org/searchlight/latest>`_
